/*____________________________________________________________________________*\
 *

 Copyright (c) 1997-2003 John Roy, Holger Zimmermann. All rights reserved.

 These sources, libraries and applications are
 FREE FOR COMMERCIAL AND NON-COMMERCIAL USE
 as long as the following conditions are adhered to.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions and the following disclaimer. 

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in
    the documentation and/or other materials provided with the
    distribution.

 3. The name of the author may not be used to endorse or promote products
    derived from this software without specific prior written permission.

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE AUTHORS OR ITS CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 OF THE POSSIBILITY OF SUCH DAMAGE.

 *____________________________________________________________________________*|
 *
 * $Source: /cvsroot/pi3web/Pi3Web_200/Source/Pi2API/PIIO.h,v $
 * $Date: 2003/05/13 18:42:09 $
 *
 Description:
\*____________________________________________________________________________*/
/* $HeaderTop:$ */

#ifndef PIIO_H_
#define PIIO_H_

#include "PIObject.h"

/*____________________________________________________________________________*\
 *
Typedefs and function prototypes
\*____________________________________________________________________________*/

/*____________________________________________________________________________*\
 *
 Name:
	PIIO_in

 Synopsis:
	int PIIO_in( PIObject *pObj, void *pData, int iLen, int *piReceived,
		int iArgc, const char *ppArgv[] )
	
 Description:
	Read a block of data from the IO object <B>pObj</B> into the buffer
	<B>pData</B>. Up to
	<B>iLen</B> bytes may be read. On success the number bytes read is written
	to the integer pointer to by <B>piReceived</B>

	Optional additional parameters may be passed to the IO object, the
	parameters <B>iArgc</B> and <B>ppArgv</B> specify the number of elements in
	an array of values and the array of values respectively.

 Notes:
	On normal channel close (gracefull socket or pipe close) PIAPI_COMPLETED
	is returned and the value at <B>piReceived</B> set to zero.

 Return Values:
	On success PIAPI_COMPLETED is returned. 

 Errors:
	On error PIAPI_ERROR is returned.

 See Also:
	PIIO_out
\*____________________________________________________________________________*/
PUBLIC_PIAPI int PIIO_in( PIObject *pObj, void *pData, int iLen,
	int *piReceived, int iArgc, const char *ppArgv[] );

/*____________________________________________________________________________*\
 *
 Name:
	PIIO_out

 Synopsis:
	int PIIO_out( PIObject *pObj, void *pData, int iLen, int *piSent,
		int iArgc, const char *ppArgv[] )
	
 Description:
	Send a block of data in buffer <B>pData</B> with length <B>iLen</B> into
	the IO object <B>pObj</B>. On success the value at <B>piSent</B> is set
	to the number of bytes written.

	Optional additional parameters may be passed to the IO object, the
	parameters <B>iArgc</B> and <B>ppArgv</B> specify the number of elements in
	an array of values and the array of values respectively.

 Notes:
 Return Values:
	On success PIAPI_COMPLETED is returned. 

 Errors:
	On error PIAPI_ERROR is returned.

 See Also:
	PIIO_in
\*____________________________________________________________________________*/
PUBLIC_PIAPI int 	PIIO_out( PIObject *pObj, void *pData, int iLen,
	int *piSent, int iArgc, const char *ppArgv[] );

#endif	/* PIIO_H_ */

